format_source_document

Function format_source_document 

pub fn format_source_document(source: &SourceDocument) -> String
Format a SourceDocument to Eure source string.

This produces output that can be parsed back to an equivalent EureDocument. Comments and section ordering from the source structure are preserved.