pub fn format_source_document(source: &SourceDocument) -> StringExpand description
Format a SourceDocument to Eure source string.
This produces output that can be parsed back to an equivalent EureDocument. Comments and section ordering from the source structure are preserved.